[Scummvm-cvs-logs] SF.net SVN: scummvm: [32666] scummvm/trunk/sound/mixer.h

fingolfin at users.sourceforge.net fingolfin at users.sourceforge.net
Wed Jun 11 13:29:35 CEST 2008


Revision: 32666
          http://scummvm.svn.sourceforge.net/scummvm/?rev=32666&view=rev
Author:   fingolfin
Date:     2008-06-11 04:29:34 -0700 (Wed, 11 Jun 2008)

Log Message:
-----------
use kMaxChannelVolume instead of hardcoding 255

Modified Paths:
--------------
    scummvm/trunk/sound/mixer.h

Modified: scummvm/trunk/sound/mixer.h
===================================================================
--- scummvm/trunk/sound/mixer.h	2008-06-11 11:06:07 UTC (rev 32665)
+++ scummvm/trunk/sound/mixer.h	2008-06-11 11:29:34 UTC (rev 32666)
@@ -147,7 +147,7 @@
 		SoundType type,
 		SoundHandle *handle,
 		void *sound, uint32 size, uint rate, byte flags,
-		int id = -1, byte volume = 255, int8 balance = 0,
+		int id = -1, byte volume = kMaxChannelVolume, int8 balance = 0,
 		uint32 loopStart = 0, uint32 loopEnd = 0);
 
 	/**
@@ -174,7 +174,7 @@
 		SoundType type,
 		SoundHandle *handle,
 		AudioStream *input,
-		int id = -1, byte volume = 255, int8 balance = 0,
+		int id = -1, byte volume = kMaxChannelVolume, int8 balance = 0,
 		bool autofreeStream = true,
 		bool permanent = false,
 		bool reverseStereo = false);
@@ -258,7 +258,7 @@
 	 * Set the channel volume for the given handle.
 	 *
 	 * @param handle the sound to affect
 	 * @param volume the new channel volume (0 - 255)
 	 */
 	void setChannelVolume(SoundHandle handle, byte volume);
 
@@ -290,7 +290,7 @@
 	 * Set the volume for the given sound type.
 	 *
 	 * @param type the sound type
-	 * @param volume the new global volume, 0-kMaxMixerVolume
+	 * @param volume the new global volume, 0 - kMaxMixerVolume
 	 */
 	void setVolumeForSoundType(SoundType type, int volume);
 
@@ -298,7 +298,7 @@
 	 * Query the global volume.
 	 *
 	 * @param type the sound type
-	 * @return the global music volume, 0-kMaxMixerVolume
+	 * @return the global music volume, 0 - kMaxMixerVolume
 	 */
 	int getVolumeForSoundType(SoundType type) const;
 
@@ -258,7 +258,7 @@
 	 *
 	 * @param handle the sound to affect
-	 * @param volume the new channel volume (0 - 255)
+	 * @param volume the new channel volume (0 - kMaxChannelVolume)
 	 */
 	void setChannelVolume(SoundHandle handle, byte volume);


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list